@@ -11,12 +11,12 @@ from googleapiclient import discovery
 # noinspection PyProtectedMember
 from googleapiclient.discovery import Resource
 from googleapiclient.errors import HttpError
+from jsonpatch import JsonPatch
 from pydantic import Field, PrivateAttr, field_validator
 
 from prefect.logging.loggers import PrefectLogAdapter
 from prefect.utilities.asyncutils import run_sync_in_worker_thread
 from prefect.utilities.dockerutils import get_prefect_image_name
-from prefect.utilities.pydantic import JsonPatch
 from prefect.workers.base import (
     BaseJobConfiguration,
     BaseVariables,
@@ -28,9 +28,8 @@ from prefect_gcp.models.cloud_run_v2 import ExecutionV2, JobV2, SecretKeySelecto
 from prefect_gcp.utilities import slugify_name
 
 if TYPE_CHECKING:
-    from prefect.client.schemas import FlowRun
-    from prefect.server.schemas.core import Flow
-    from prefect.server.schemas.responses import DeploymentResponse
+    from prefect.client.schemas.objects import Flow, FlowRun, WorkPool
+    from prefect.client.schemas.responses import DeploymentResponse
 
 
 def _get_default_job_body_template() -> Dict[str, Any]:
@@ -106,6 +105,11 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         title="Environment Variables from Secrets",
         description="Environment variables to set from GCP secrets when starting a flow run.",
     )
+    cloudsql_instances: Optional[List[str]] = Field(
+        default_factory=list,
+        title="Cloud SQL Instances",
+        description="List of Cloud SQL instance connection names to connect to. Format: {project}:{location}:{instance}",
+    )
     job_body: Dict[str, Any] = Field(
         json_schema_extra=dict(template=_get_default_job_body_template()),
     )
@@ -121,10 +125,10 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
     timeout: int = Field(
         default=600,
         gt=0,
-        le=86400,
+        le=604800,
         description=(
             "Max allowed duration the Job may be active before Cloud Run will "
-            "actively try to mark it failed and kill associated containers (maximum of 86400 seconds, 1 day)."
+            "actively try to mark it failed and kill associated containers (maximum of 604800 seconds, 7 days)."
         ),
     )
     _job_name: str = PrivateAttr(default=None)
@@ -159,6 +163,8 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         flow_run: "FlowRun",
         deployment: Optional["DeploymentResponse"] = None,
         flow: Optional["Flow"] = None,
+        work_pool: Optional["WorkPool"] = None,
+        worker_name: Optional[str] = None,
     ):
         """
         Prepares the job configuration for a flow run.
@@ -171,14 +177,19 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
             deployment: The deployment associated with the flow run used for
                 preparation.
             flow: The flow associated with the flow run used for preparation.
+            work_pool: The work pool associated with the flow run used for preparation.
+            worker_name: The worker name associated with the flow run used for preparation.
         """
         super().prepare_for_flow_run(
             flow_run=flow_run,
             deployment=deployment,
             flow=flow,
+            work_pool=work_pool,
+            worker_name=worker_name,
         )
 
         self._populate_env()
+        self._configure_cloudsql_volumes()
         self._populate_or_format_command()
         self._format_args_if_present()
         self._populate_image_if_not_present()
@@ -205,16 +216,40 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         ]
         envs.extend(envs_from_secrets)
 
-        self.job_body["template"]["template"]["containers"][0]["env"] = envs
+        self.job_body["template"]["template"]["containers"][0]["env"].extend(envs)
+
+    def _configure_cloudsql_volumes(self):
+        """
+        Populates volumes and volume mounts for cloudsql instances
+        """
+
+        if not self.cloudsql_instances:
+            return
+
+        template = self.job_body["template"]["template"]
+        containers = template["containers"]
+        if "volumes" not in template:
+            template["volumes"] = []
+        template["volumes"].append(
+            {
+                "name": "cloudsql",
+                "cloudSqlInstance": {"instances": self.cloudsql_instances},
+            }
+        )
+        if "volumeMounts" not in containers[0]:
+            containers[0]["volumeMounts"] = []
+        containers[0]["volumeMounts"].append(
+            {"name": "cloudsql", "mountPath": "/cloudsql"}
+        )
 
     def _populate_image_if_not_present(self):
         """
         Populates the job body with the image if not present.
         """
         if "image" not in self.job_body["template"]["template"]["containers"][0]:
-            self.job_body["template"]["template"]["containers"][0][
-                "image"
-            ] = f"docker.io/{get_prefect_image_name()}"
+            self.job_body["template"]["template"]["containers"][0]["image"] = (
+                f"docker.io/{get_prefect_image_name()}"
+            )
 
     def _populate_or_format_command(self):
         """
@@ -223,13 +258,13 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         command = self.job_body["template"]["template"]["containers"][0].get("command")
 
         if command is None:
-            self.job_body["template"]["template"]["containers"][0][
-                "command"
-            ] = shlex.split(self._base_flow_run_command())
+            self.job_body["template"]["template"]["containers"][0]["command"] = (
+                shlex.split(self._base_flow_run_command())
+            )
         elif isinstance(command, str):
-            self.job_body["template"]["template"]["containers"][0][
-                "command"
-            ] = shlex.split(command)
+            self.job_body["template"]["template"]["containers"][0]["command"] = (
+                shlex.split(command)
+            )
 
     def _format_args_if_present(self):
         """
@@ -238,9 +273,9 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         args = self.job_body["template"]["template"]["containers"][0].get("args")
 
         if args is not None and isinstance(args, str):
-            self.job_body["template"]["template"]["containers"][0][
-                "args"
-            ] = shlex.split(args)
+            self.job_body["template"]["template"]["containers"][0]["args"] = (
+                shlex.split(args)
+            )
 
     def _remove_vpc_access_if_unset(self):
         """
@@ -344,12 +379,20 @@ class CloudRunWorkerV2Variables(BaseVariables):
         default_factory=dict,
         title="Environment Variables from Secrets",
         description="Environment variables to set from GCP secrets when starting a flow run.",
-        example={
-            "ENV_VAR_NAME": {
-                "secret": "SECRET_NAME",
-                "version": "latest",
+        examples=[
+            {
+                "ENV_VAR_NAME": {
+                    "secret": "SECRET_NAME",
+                    "version": "latest",
+                }
             }
-        },
+        ],
+    )
+    cloudsql_instances: Optional[List[str]] = Field(
+        default_factory=list,
+        title="Cloud SQL Instances",
+        description="List of Cloud SQL instance connection names to connect to. Format: {project}:{location}:{instance}",
+        examples=["project:region:instance-id"],
     )
     keep_job: bool = Field(
         default=False,
@@ -426,7 +469,13 @@ class CloudRunWorkerV2Result(BaseWorkerResult):
     """
 
 
-class CloudRunWorkerV2(BaseWorker):
+class CloudRunWorkerV2(
+    BaseWorker[
+        CloudRunWorkerJobV2Configuration,
+        CloudRunWorkerV2Variables,
+        CloudRunWorkerV2Result,
+    ]
+):
     """
     The Cloud Run worker V2.
     """
@@ -436,7 +485,7 @@ class CloudRunWorkerV2(BaseWorker):
     job_configuration_variables = CloudRunWorkerV2Variables
     _description = "Execute flow runs within containers on Google Cloud Run (V2 API). Requires a Google Cloud Platform account."  # noqa
     _display_name = "Google Cloud Run V2"
-    _documentation_url = "https://prefecthq.github.io/prefect-gcp/worker_v2/"
+    _documentation_url = "https://docs.prefect.io/integrations/prefect-gcp"
     _logo_url = "https://images.ctfassets.net/gm98wzqotmnx/4SpnOBvMYkHp6z939MDKP6/549a91bc1ce9afd4fb12c68db7b68106/social-icon-google-cloud-1200-630.png?h=250"  # noqa
 
     async def run(
@@ -715,8 +764,7 @@ class CloudRunWorkerV2(BaseWorker):
             )
         except Exception as exc:
             logger.critical(
-                f"Encountered an exception while waiting for job run completion - "
-                f"{exc}"
+                f"Encountered an exception while waiting for job run completion - {exc}"
             )
             raise
 
