@@ -28,11 +28,11 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple
 from uuid import uuid4
 
 import anyio
+from jsonpatch import JsonPatch
 from pydantic import Field, field_validator
 from slugify import slugify
 
 from prefect.logging.loggers import PrefectLogAdapter
-from prefect.utilities.pydantic import JsonPatch
 from prefect.workers.base import (
     BaseJobConfiguration,
     BaseVariables,
@@ -55,7 +55,6 @@ try:
     )
     from google.cloud.aiplatform_v1.types.job_state import JobState
     from google.cloud.aiplatform_v1.types.machine_resources import DiskSpec, MachineSpec
-    from google.protobuf.duration_pb2 import Duration
     from tenacity import AsyncRetrying, stop_after_attempt, wait_fixed, wait_random
 except ModuleNotFoundError:
     pass
@@ -63,9 +62,8 @@ except ModuleNotFoundError:
 _DISALLOWED_GCP_LABEL_CHARACTERS = re.compile(r"[^-a-zA-Z0-9_]+")
 
 if TYPE_CHECKING:
-    from prefect.client.schemas import FlowRun
-    from prefect.server.schemas.core import Flow
-    from prefect.server.schemas.responses import DeploymentResponse
+    from prefect.client.schemas.objects import Flow, FlowRun, WorkPool
+    from prefect.client.schemas.responses import DeploymentResponse
 
 
 class VertexAIWorkerVariables(BaseVariables):
@@ -156,6 +154,22 @@ class VertexAIWorkerVariables(BaseVariables):
         "within the provided ip ranges. Otherwise, the job will be deployed to "
         "any ip ranges under the provided VPC network.",
     )
+    scheduling: Optional[dict[str, Any]] = Field(
+        default=None,
+        title="Scheduling Options",
+        description=(
+            "A dictionary with scheduling options for a CustomJob, "
+            "these are parameters related to queuing, and scheduling custom jobs. "
+            "If unspecified default scheduling options are used. "
+            "The 'maximum_run_time_hours' variable sets the job timeout "
+            "field 'scheduling.timeout' for backward compatibility. "
+            "See SDK: https://cloud.google.com/python/docs/reference/aiplatform/latest/google.cloud.aiplatform_v1.types.Scheduling "
+            "See REST: https://cloud.google.com/vertex-ai/docs/reference/rest/v1/CustomJobSpec#Scheduling"
+        ),
+        examples=[
+            {"scheduling": {"strategy": "FLEX_START", "max_wait_duration": "1800s"}}
+        ],
+    )
     service_account_name: Optional[str] = Field(
         default=None,
         title="Service Account Name",
@@ -168,6 +182,24 @@ class VertexAIWorkerVariables(BaseVariables):
             "and required if a service account cannot be detected in GCP credentials."
         ),
     )
+    enable_web_access: bool = Field(
+        default=False,
+        title="Enable Web Access",
+        description=(
+            "Whether you want Vertex AI to enable `interactive shell access` "
+            "See https://cloud.google.com/vertex-ai/docs/training/monitor-debug-interactive-shell for how to access your job via interactive console when running."
+        ),
+        examples=[True],
+    )
+    enable_dashboard_access: bool = Field(
+        default=False,
+        title="Enable Dashboard Access",
+        description=(
+            "Whether to enable access to the customized dashboard in the training chief container. "
+            "See https://cloud.google.com/vertex-ai/docs/training/monitor-debug-interactive-shell#get-uri for access instructions."
+        ),
+        examples=[True],
+    )
     job_watch_poll_interval: float = Field(
         default=5.0,
         title="Poll Interval (Seconds)",
@@ -235,6 +267,9 @@ class VertexAIWorkerJobConfiguration(BaseJobConfiguration):
                 "network": "{{ network }}",
                 "reserved_ip_ranges": "{{ reserved_ip_ranges }}",
                 "maximum_run_time_hours": "{{ maximum_run_time_hours }}",
+                "scheduling": "{{ scheduling }}",
+                "enable_web_access": "{{ enable_web_access }}",
+                "enable_dashboard_access": "{{ enable_dashboard_access }}",
                 "worker_pool_specs": [
                     {
                         "replica_count": 1,
@@ -286,8 +321,10 @@ class VertexAIWorkerJobConfiguration(BaseJobConfiguration):
         flow_run: "FlowRun",
         deployment: Optional["DeploymentResponse"] = None,
         flow: Optional["Flow"] = None,
+        work_pool: Optional["WorkPool"] = None,
+        worker_name: Optional[str] = None,
     ):
-        super().prepare_for_flow_run(flow_run, deployment, flow)
+        super().prepare_for_flow_run(flow_run, deployment, flow, work_pool, worker_name)
 
         self._inject_formatted_env_vars()
         self._inject_formatted_command()
@@ -361,7 +398,11 @@ class VertexAIWorkerResult(BaseWorkerResult):
     """Contains information about the final state of a completed process"""
 
 
-class VertexAIWorker(BaseWorker):
+class VertexAIWorker(
+    BaseWorker[
+        VertexAIWorkerJobConfiguration, VertexAIWorkerVariables, VertexAIWorkerResult
+    ]
+):
     """Prefect worker that executes flow runs within Vertex AI Jobs."""
 
     type = "vertex-ai"
@@ -372,7 +413,7 @@ class VertexAIWorker(BaseWorker):
         "a Google Cloud Platform account."
     )
     _display_name = "Google Vertex AI"
-    _documentation_url = "https://prefecthq.github.io/prefect-gcp/vertex_worker/"
+    _documentation_url = "https://docs.prefect.io/integrations/prefect-gcp"  # noqa
     _logo_url = "https://cdn.sanity.io/images/3ugk85nk/production/10424e311932e31c477ac2b9ef3d53cefbaad708-250x250.png"  # noqa
 
     async def run(
@@ -471,12 +512,21 @@ class VertexAIWorker(BaseWorker):
             for spec in configuration.job_spec.pop("worker_pool_specs", [])
         ]
 
-        timeout = Duration().FromTimedelta(
-            td=datetime.timedelta(
-                hours=configuration.job_spec["maximum_run_time_hours"]
-            )
-        )
-        scheduling = Scheduling(timeout=timeout)
+        scheduling = Scheduling()
+
+        if "scheduling" in configuration.job_spec:
+            scheduling_params = configuration.job_spec.pop("scheduling")
+            # allow users to pass 'scheduling.strategy' as str
+            if scheduling_params and type(scheduling_params.get("strategy")) is str:
+                scheduling_params["strategy"] = Scheduling.Strategy[
+                    scheduling_params["strategy"]
+                ]
+                scheduling = Scheduling(**scheduling_params)
+
+        # set 'scheduling.timeout' using "maximum_run_time_hours" for backward compatibility
+        if "maximum_run_time_hours" in configuration.job_spec:
+            maximum_run_time_hours = configuration.job_spec["maximum_run_time_hours"]
+            scheduling.timeout = str(maximum_run_time_hours * 60 * 60) + "s"
 
         if "service_account_name" in configuration.job_spec:
             service_account_name = configuration.job_spec.pop("service_account_name")
@@ -525,8 +575,7 @@ class VertexAIWorker(BaseWorker):
                 )
 
         logger.info(
-            f"Job {job_name!r} created. "
-            f"The full job name is {custom_job_run.name!r}"
+            f"Job {job_name!r} created. The full job name is {custom_job_run.name!r}"
         )
 
         return custom_job_run
