@@ -120,6 +120,29 @@ class TestCloudRunWorkerJobV2Configuration:
             },
         ]
 
+    def test_populate_env_with_existing_envs(self, cloud_run_worker_v2_job_config):
+        cloud_run_worker_v2_job_config.job_body["template"]["template"]["containers"][
+            0
+        ]["env"] = [{"name": "ENV0", "value": "VALUE0"}]
+        cloud_run_worker_v2_job_config.env_from_secrets = {
+            "SECRET_ENV1": SecretKeySelector(secret="SECRET1", version="latest")
+        }
+        cloud_run_worker_v2_job_config._populate_env()
+
+        assert cloud_run_worker_v2_job_config.job_body["template"]["template"][
+            "containers"
+        ][0]["env"] == [
+            {"name": "ENV0", "value": "VALUE0"},
+            {"name": "ENV1", "value": "VALUE1"},
+            {"name": "ENV2", "value": "VALUE2"},
+            {
+                "name": "SECRET_ENV1",
+                "valueSource": {
+                    "secretKeyRef": {"secret": "SECRET1", "version": "latest"}
+                },
+            },
+        ]
+
     def test_populate_image_if_not_present(self, cloud_run_worker_v2_job_config):
         cloud_run_worker_v2_job_config._populate_image_if_not_present()
 
@@ -148,9 +171,9 @@ class TestCloudRunWorkerJobV2Configuration:
     def test_remove_vpc_access_if_connector_unset(
         self, cloud_run_worker_v2_job_config, vpc_access
     ):
-        cloud_run_worker_v2_job_config.job_body["template"]["template"][
-            "vpcAccess"
-        ] = vpc_access
+        cloud_run_worker_v2_job_config.job_body["template"]["template"]["vpcAccess"] = (
+            vpc_access
+        )
 
         cloud_run_worker_v2_job_config._remove_vpc_access_if_unset()
 
@@ -203,3 +226,68 @@ class TestCloudRunWorkerJobV2Configuration:
                 {"network": "projects/my_project/global/networks/my-network"}
             ],
         }
+
+    def test_configure_cloudsql_volumes_no_instances(
+        self, cloud_run_worker_v2_job_config
+    ):
+        cloud_run_worker_v2_job_config.cloudsql_instances = []
+        cloud_run_worker_v2_job_config._configure_cloudsql_volumes()
+
+        template = cloud_run_worker_v2_job_config.job_body["template"]["template"]
+
+        assert "volumes" not in template
+        assert "volumeMounts" not in template["containers"][0]
+
+    def test_configure_cloudsql_volumes_preserves_existing_volumes(
+        self, cloud_run_worker_v2_job_config
+    ):
+        template = cloud_run_worker_v2_job_config.job_body["template"]["template"]
+        template["volumes"] = [{"name": "existing-volume", "emptyDir": {}}]
+        template["containers"][0]["volumeMounts"] = [
+            {"name": "existing-volume", "mountPath": "/existing"}
+        ]
+
+        cloud_run_worker_v2_job_config.cloudsql_instances = ["project:region:instance1"]
+        cloud_run_worker_v2_job_config._configure_cloudsql_volumes()
+
+        assert len(template["volumes"]) == 2
+        assert template["volumes"][0] == {"name": "existing-volume", "emptyDir": {}}
+        assert template["volumes"][1] == {
+            "name": "cloudsql",
+            "cloudSqlInstance": {"instances": ["project:region:instance1"]},
+        }
+
+        assert len(template["containers"][0]["volumeMounts"]) == 2
+        assert template["containers"][0]["volumeMounts"][0] == {
+            "name": "existing-volume",
+            "mountPath": "/existing",
+        }
+        assert template["containers"][0]["volumeMounts"][1] == {
+            "name": "cloudsql",
+            "mountPath": "/cloudsql",
+        }
+
+    def test_prepare_for_flow_run_configures_cloudsql(
+        self, cloud_run_worker_v2_job_config
+    ):
+        cloud_run_worker_v2_job_config.cloudsql_instances = ["project:region:instance1"]
+
+        class MockFlowRun:
+            id = "test-id"
+            name = "test-run"
+
+        cloud_run_worker_v2_job_config.prepare_for_flow_run(
+            flow_run=MockFlowRun(), deployment=None, flow=None
+        )
+
+        template = cloud_run_worker_v2_job_config.job_body["template"]["template"]
+
+        assert any(
+            vol["name"] == "cloudsql"
+            and vol["cloudSqlInstance"]["instances"] == ["project:region:instance1"]
+            for vol in template["volumes"]
+        )
+        assert any(
+            mount["name"] == "cloudsql" and mount["mountPath"] == "/cloudsql"
+            for mount in template["containers"][0]["volumeMounts"]
+        )
